#[non_exhaustive]pub struct CreateOrderRejectBody {
pub order_reject_transaction: Option<Transaction>,
pub related_transaction_ids: Vec<TransactionId>,
pub last_transaction_id: Option<TransactionId>,
}Expand description
Typed view of the error body when Client::create_order or
Client::replace_order is rejected (HTTP 400/404). Recover it via
ApiErrorBody::details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.order_reject_transaction: Option<Transaction>The transaction that rejected the creation of the order.
The IDs of all transactions created while satisfying the request.
last_transaction_id: Option<TransactionId>The ID of the most recent transaction created for the account.