#[non_exhaustive]pub struct CreateOrderResponse {
pub order_create_transaction: Transaction,
pub order_fill_transaction: Option<OrderFillTransaction>,
pub order_cancel_transaction: Option<OrderCancelTransaction>,
pub order_reissue_transaction: Option<Transaction>,
pub order_reissue_reject_transaction: Option<Transaction>,
pub related_transaction_ids: Vec<TransactionId>,
pub last_transaction_id: Option<TransactionId>,
pub location: Option<String>,
}Expand description
Response of Client::create_order (HTTP 201).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.order_create_transaction: TransactionThe transaction that created the order.
order_fill_transaction: Option<OrderFillTransaction>The transaction that filled the order (only for market orders, or orders that were immediately filled).
order_cancel_transaction: Option<OrderCancelTransaction>The transaction that cancelled the order (only when the order was immediately cancelled).
order_reissue_transaction: Option<Transaction>The transaction that reissued the order (only when the order was partially filled and reissued).
order_reissue_reject_transaction: Option<Transaction>The transaction that rejected the reissue of the order.
The IDs of all transactions created while satisfying the request.
last_transaction_id: Option<TransactionId>The ID of the most recent transaction created for the account.
location: Option<String>The Location response header: the URL of the created order.