#[non_exhaustive]pub struct SetOrderClientExtensionsResponse {
pub order_client_extensions_modify_transaction: Option<OrderClientExtensionsModifyTransaction>,
pub related_transaction_ids: Vec<TransactionId>,
pub last_transaction_id: Option<TransactionId>,
}Expand description
Response of Client::set_order_client_extensions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.order_client_extensions_modify_transaction: Option<OrderClientExtensionsModifyTransaction>The transaction that modified the client extensions.
The IDs of all transactions created while satisfying the request.
last_transaction_id: Option<TransactionId>The ID of the most recent transaction created for the account.