#[non_exhaustive]pub enum TimeInForce {
Gtc,
Gtd,
Gfd,
Fok,
Ioc,
Other(String),
}Expand description
The time-in-force of an Order. TimeInForce describes how long an Order should remain pending before being automatically cancelled by the execution system.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Gtc
GTC.
Gtd
GTD.
Gfd
GFD.
Fok
FOK.
Ioc
IOC.
Other(String)
A value not (yet) known to this version of the SDK.
Implementations