pub struct CandleSpecification {
pub instrument: InstrumentName,
pub granularity: CandlestickGranularity,
pub price: Option<PricingComponent>,
}Expand description
An instrument name, a granularity, and a price component to get
candlestick data for, e.g. EUR_USD:S10:BM.
Fields
instrument: InstrumentNameThe instrument to get candles for.
granularity: CandlestickGranularityThe candlestick granularity.
price: Option<PricingComponent>The price component(s); OANDA defaults to mid when omitted.
Implementations
Sourceimpl CandleSpecification
impl CandleSpecification
Sourcepub fn new(
instrument: impl Into<InstrumentName>,
granularity: CandlestickGranularity,
) -> Self
pub fn new( instrument: impl Into<InstrumentName>, granularity: CandlestickGranularity, ) -> Self
A specification for the given instrument and granularity (mid price).
Sourcepub fn price(self, price: PricingComponent) -> Self
pub fn price(self, price: PricingComponent) -> Self
Selects the price component(s) for this specification.