ClientPrice

Struct ClientPrice 

#[non_exhaustive]
pub struct ClientPrice { pub type: Option<String>, pub instrument: Option<InstrumentName>, pub time: Option<DateTime>, pub status: Option<PriceStatus>, pub tradeable: Option<bool>, pub bids: Vec<PriceBucket>, pub asks: Vec<PriceBucket>, pub closeout_bid: Option<PriceValue>, pub closeout_ask: Option<PriceValue>, pub quote_home_conversion_factors: Option<QuoteHomeConversionFactors>, pub units_available: Option<UnitsAvailable>, pub timestamp: Option<DateTime>, }
The specification of an Account-specific Price.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
type: Option<String>

The type discriminator, always PRICE.

instrument: Option<InstrumentName>

The Price’s Instrument.

time: Option<DateTime>

The date/time when the Price was created

status: Option<PriceStatus>

The status field.

tradeable: Option<bool>

Flag indicating if the Price is tradeable or not

bids: Vec<PriceBucket>

The list of prices and liquidity available on the Instrument’s bid side. It is possible for this list to be empty if there is no bid liquidity currently available for the Instrument in the Account.

asks: Vec<PriceBucket>

The list of prices and liquidity available on the Instrument’s ask side. It is possible for this list to be empty if there is no ask liquidity currently available for the Instrument in the Account.

closeout_bid: Option<PriceValue>

The closeout bid Price. This Price is used when a bid is required to closeout a Position (margin closeout or manual) yet there is no bid liquidity. The closeout bid is never used to open a new position.

closeout_ask: Option<PriceValue>

The closeout ask Price. This Price is used when a ask is required to closeout a Position (margin closeout or manual) yet there is no ask liquidity. The closeout ask is never used to open a new position.

quote_home_conversion_factors: Option<QuoteHomeConversionFactors>

The quoteHomeConversionFactors field.

units_available: Option<UnitsAvailable>

The unitsAvailable field.

timestamp: Option<DateTime>

The date/time when the Price was created. This field is returned by the live v20 API but is not present in OANDA’s official documentation.