#[non_exhaustive]pub struct ConversionFactor {
pub factor: Option<DecimalNumber>,
}Expand description
A ConversionFactor contains information used to convert an amount, from an Instrument’s base or quote currency, to the home currency of an Account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.factor: Option<DecimalNumber>The factor by which to multiply the amount in the given currency to obtain the amount in the home currency of the Account.