#[non_exhaustive]pub struct FixedPriceOrder {Show 20 fields
pub id: Option<OrderId>,
pub create_time: Option<DateTime>,
pub state: Option<OrderState>,
pub client_extensions: Option<ClientExtensions>,
pub instrument: Option<InstrumentName>,
pub units: Option<DecimalNumber>,
pub price: Option<PriceValue>,
pub position_fill: Option<OrderPositionFill>,
pub trade_state: Option<TradeState>,
pub take_profit_on_fill: Option<TakeProfitDetails>,
pub stop_loss_on_fill: Option<StopLossDetails>,
pub trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>,
pub trade_client_extensions: Option<ClientExtensions>,
pub filling_transaction_id: Option<TransactionId>,
pub filled_time: Option<DateTime>,
pub trade_opened_id: Option<TradeId>,
pub trade_reduced_id: Option<TradeId>,
pub trade_closed_ids: Vec<TradeId>,
pub cancelling_transaction_id: Option<TransactionId>,
pub cancelled_time: Option<DateTime>,
}Expand description
A FixedPriceOrder is an order that is filled immediately upon creation using a fixed price.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<OrderId>The Order’s identifier, unique within the Order’s Account.
create_time: Option<DateTime>The time when the Order was created.
state: Option<OrderState>The state field.
client_extensions: Option<ClientExtensions>The clientExtensions field.
instrument: Option<InstrumentName>The Fixed Price Order’s Instrument.
units: Option<DecimalNumber>The quantity requested to be filled by the Fixed Price Order. A posititive number of units results in a long Order, and a negative number of units results in a short Order.
price: Option<PriceValue>The price specified for the Fixed Price Order. This price is the exact price that the Fixed Price Order will be filled at.
position_fill: Option<OrderPositionFill>The positionFill field.
trade_state: Option<TradeState>The tradeState field.
take_profit_on_fill: Option<TakeProfitDetails>The takeProfitOnFill field.
stop_loss_on_fill: Option<StopLossDetails>The stopLossOnFill field.
trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>The trailingStopLossOnFill field.
trade_client_extensions: Option<ClientExtensions>The tradeClientExtensions field.
filling_transaction_id: Option<TransactionId>ID of the Transaction that filled this Order (only provided when the Order’s state is FILLED)
filled_time: Option<DateTime>Date/time when the Order was filled (only provided when the Order’s state is FILLED)
trade_opened_id: Option<TradeId>Trade ID of Trade opened when the Order was filled (only provided when the Order’s state is FILLED and a Trade was opened as a result of the fill)
trade_reduced_id: Option<TradeId>Trade ID of Trade reduced when the Order was filled (only provided when the Order’s state is FILLED and a Trade was reduced as a result of the fill)
trade_closed_ids: Vec<TradeId>Trade IDs of Trades closed when the Order was filled (only provided when the Order’s state is FILLED and one or more Trades were closed as a result of the fill)
cancelling_transaction_id: Option<TransactionId>ID of the Transaction that cancelled the Order (only provided when the Order’s state is CANCELLED)
cancelled_time: Option<DateTime>Date/time when the Order was cancelled (only provided when the state of the Order is CANCELLED)