#[non_exhaustive]pub struct HomeConversionFactors {
pub gain_quote_home: Option<ConversionFactor>,
pub loss_quote_home: Option<ConversionFactor>,
pub gain_base_home: Option<ConversionFactor>,
pub loss_base_home: Option<ConversionFactor>,
}Expand description
A HomeConversionFactors message contains information used to convert amounts, from an Instrument’s base or quote currency, to the home currency of an Account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.gain_quote_home: Option<ConversionFactor>The gainQuoteHome field.
loss_quote_home: Option<ConversionFactor>The lossQuoteHome field.
gain_base_home: Option<ConversionFactor>The gainBaseHome field.
loss_base_home: Option<ConversionFactor>The lossBaseHome field.