#[non_exhaustive]pub struct MarketOrderDelayedTradeClose {
pub trade_id: Option<TradeId>,
pub client_trade_id: Option<TradeId>,
pub source_transaction_id: Option<TransactionId>,
}Expand description
Details for the Market Order extensions specific to a Market Order placed with the intent of fully closing a specific open trade that should have already been closed but wasn’t due to halted market conditions
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trade_id: Option<TradeId>The ID of the Trade being closed
client_trade_id: Option<TradeId>The Client ID of the Trade being closed
source_transaction_id: Option<TransactionId>The Transaction ID of the DelayedTradeClosure transaction to which this Delayed Trade Close belongs to