#[non_exhaustive]pub struct MarketOrderPositionCloseout {
pub instrument: Option<InstrumentName>,
pub units: Option<String>,
}Expand description
A MarketOrderPositionCloseout specifies the extensions to a Market Order when it has been created to closeout a specific Position.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instrument: Option<InstrumentName>The instrument of the Position being closed out.
units: Option<String>Indication of how much of the Position to close. Either “ALL”, or a DecimalNumber reflection a partial close of the Trade. The DecimalNumber must always be positive, and represent a number that doesn’t exceed the absolute size of the Position.