#[non_exhaustive]pub struct MarketOrderTradeClose {
pub trade_id: Option<TradeId>,
pub client_trade_id: Option<String>,
pub units: Option<String>,
}Expand description
A MarketOrderTradeClose specifies the extensions to a Market Order that has been created specifically to close a Trade.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trade_id: Option<TradeId>The ID of the Trade requested to be closed
client_trade_id: Option<String>The client ID of the Trade requested to be closed
units: Option<String>Indication of how much of the Trade to close. Either “ALL”, or a DecimalNumber reflection a partial close of the Trade.