#[non_exhaustive]pub struct OpenTradeFinancing {
pub trade_id: Option<TradeId>,
pub financing: Option<AccountUnits>,
pub base_financing: Option<DecimalNumber>,
pub financing_rate: Option<DecimalNumber>,
pub home_conversion_cost: Option<DecimalNumber>,
pub base_home_conversion_cost: Option<DecimalNumber>,
}Expand description
OpenTradeFinancing is used to pay/collect daily financing charge for an open Trade within an Account
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trade_id: Option<TradeId>The ID of the Trade that financing is being paid/collected for.
financing: Option<AccountUnits>The amount of financing paid/collected for the Trade.
base_financing: Option<DecimalNumber>The amount of financing paid/collected in the Instrument’s base currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.
financing_rate: Option<DecimalNumber>The financing rate in effect for the Trade. This field is returned by the live v20 API but is not present in OANDA’s official documentation.
home_conversion_cost: Option<DecimalNumber>The total cost of currency conversions for the Trade’s financing, in the Account’s home currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.
base_home_conversion_cost: Option<DecimalNumber>The cost of converting the base financing to the Account’s home currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.