#[non_exhaustive]pub struct PositionBookBucket {
pub price: Option<PriceValue>,
pub long_count_percent: Option<DecimalNumber>,
pub short_count_percent: Option<DecimalNumber>,
}Expand description
The position book data for a partition of the instrument’s prices.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.price: Option<PriceValue>The lowest price (inclusive) covered by the bucket. The bucket covers the price range from the price to price + the position book’s bucketWidth.
long_count_percent: Option<DecimalNumber>The percentage of the total number of positions represented by the long positions found in this bucket.
short_count_percent: Option<DecimalNumber>The percentage of the total number of positions represented by the short positions found in this bucket.