PositionFinancing

Struct PositionFinancing 

#[non_exhaustive]
pub struct PositionFinancing { pub instrument: Option<InstrumentName>, pub financing: Option<AccountUnits>, pub open_trade_financings: Vec<OpenTradeFinancing>, pub base_financing: Option<DecimalNumber>, pub account_financing_mode: Option<AccountFinancingMode>, pub home_conversion_factors: Option<HomeConversionFactors>, pub home_conversion_cost: Option<DecimalNumber>, pub base_home_conversion_cost: Option<DecimalNumber>, }
OpenTradeFinancing is used to pay/collect daily financing charge for a Position within an Account

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
instrument: Option<InstrumentName>

The instrument of the Position that financing is being paid/collected for.

financing: Option<AccountUnits>

The amount of financing paid/collected for the Position.

open_trade_financings: Vec<OpenTradeFinancing>

The financing paid/collecte for each open Trade within the Position.

base_financing: Option<DecimalNumber>

The amount of financing paid/collected in the Instrument’s base currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.

account_financing_mode: Option<AccountFinancingMode>

The accountFinancingMode field.

home_conversion_factors: Option<HomeConversionFactors>

The homeConversionFactors field.

home_conversion_cost: Option<DecimalNumber>

The total cost of currency conversions for the Position’s financing, in the Account’s home currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.

base_home_conversion_cost: Option<DecimalNumber>

The cost of converting the base financing to the Account’s home currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.