#[non_exhaustive]pub struct PriceBucket {
pub price: Option<PriceValue>,
pub liquidity: Option<DecimalNumber>,
}Expand description
A Price Bucket represents a price available for an amount of liquidity
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.price: Option<PriceValue>The Price offered by the PriceBucket
liquidity: Option<DecimalNumber>The amount of liquidity offered by the PriceBucket. The REST API encodes this as a string, the streaming API as a JSON number; OANDA documents it as “integer or decimal if available”.