StopLossOrder

Struct StopLossOrder 

#[non_exhaustive]
pub struct StopLossOrder {
Show 23 fields pub id: Option<OrderId>, pub create_time: Option<DateTime>, pub state: Option<OrderState>, pub client_extensions: Option<ClientExtensions>, pub guaranteed_execution_premium: Option<DecimalNumber>, pub trade_id: Option<TradeId>, pub client_trade_id: Option<String>, pub price: Option<PriceValue>, pub distance: Option<DecimalNumber>, pub time_in_force: Option<StopLossOrderTimeInForce>, pub gtd_time: Option<DateTime>, pub trigger_condition: Option<OrderTriggerCondition>, pub guaranteed: Option<bool>, pub filling_transaction_id: Option<TransactionId>, pub filled_time: Option<DateTime>, pub trade_opened_id: Option<TradeId>, pub trade_reduced_id: Option<TradeId>, pub trade_closed_ids: Vec<TradeId>, pub cancelling_transaction_id: Option<TransactionId>, pub cancelled_time: Option<DateTime>, pub replaces_order_id: Option<OrderId>, pub replaced_by_order_id: Option<OrderId>, pub trigger_mode: Option<String>,
}
A StopLossOrder is an order that is linked to an open Trade and created with a price threshold. The Order will be filled (closing the Trade) by the first price that is equal to or worse than the threshold. A StopLossOrder cannot be used to open a new Position.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<OrderId>

The Order’s identifier, unique within the Order’s Account.

create_time: Option<DateTime>

The time when the Order was created.

state: Option<OrderState>

The state field.

client_extensions: Option<ClientExtensions>

The clientExtensions field.

guaranteed_execution_premium: Option<DecimalNumber>

The premium that will be charged if the Stop Loss Order is guaranteed and the Order is filled at the guaranteed price. It is in price units and is charged for each unit of the Trade.

trade_id: Option<TradeId>

The ID of the Trade to close when the price threshold is breached.

client_trade_id: Option<String>

The client ID of the Trade to be closed when the price threshold is breached.

price: Option<PriceValue>

The price threshold specified for the Stop Loss Order. If the guaranteed flag is false, the associated Trade will be closed by a market price that is equal to or worse than this threshold. If the flag is true the associated Trade will be closed at this price.

distance: Option<DecimalNumber>

Specifies the distance (in price units) from the Account’s current price to use as the Stop Loss Order price. If the Trade is short the Instrument’s bid price is used, and for long Trades the ask is used.

time_in_force: Option<StopLossOrderTimeInForce>

The timeInForce field.

gtd_time: Option<DateTime>

The date/time when the StopLoss Order will be cancelled if its timeInForce is “GTD”.

trigger_condition: Option<OrderTriggerCondition>

The triggerCondition field.

guaranteed: Option<bool>

Flag indicating that the Stop Loss Order is guaranteed. The default value depends on the GuaranteedStopLossOrderMode of the account, if it is REQUIRED, the default will be true, for DISABLED or ENABLED the default is false.

filling_transaction_id: Option<TransactionId>

ID of the Transaction that filled this Order (only provided when the Order’s state is FILLED)

filled_time: Option<DateTime>

Date/time when the Order was filled (only provided when the Order’s state is FILLED)

trade_opened_id: Option<TradeId>

Trade ID of Trade opened when the Order was filled (only provided when the Order’s state is FILLED and a Trade was opened as a result of the fill)

trade_reduced_id: Option<TradeId>

Trade ID of Trade reduced when the Order was filled (only provided when the Order’s state is FILLED and a Trade was reduced as a result of the fill)

trade_closed_ids: Vec<TradeId>

Trade IDs of Trades closed when the Order was filled (only provided when the Order’s state is FILLED and one or more Trades were closed as a result of the fill)

cancelling_transaction_id: Option<TransactionId>

ID of the Transaction that cancelled the Order (only provided when the Order’s state is CANCELLED)

cancelled_time: Option<DateTime>

Date/time when the Order was cancelled (only provided when the state of the Order is CANCELLED)

replaces_order_id: Option<OrderId>

The ID of the Order that was replaced by this Order (only provided if this Order was created as part of a cancel/replace).

replaced_by_order_id: Option<OrderId>

The ID of the Order that replaced this Order (only provided if this Order was cancelled as part of a cancel/replace).

trigger_mode: Option<String>

The price trigger mode of the Order. Observed value: “TOP_OF_BOOK”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.