StopOrder

Struct StopOrder 

#[non_exhaustive]
pub struct StopOrder {
Show 27 fields pub id: Option<OrderId>, pub create_time: Option<DateTime>, pub state: Option<OrderState>, pub client_extensions: Option<ClientExtensions>, pub instrument: Option<InstrumentName>, pub units: Option<DecimalNumber>, pub price: Option<PriceValue>, pub price_bound: Option<PriceValue>, pub time_in_force: Option<StopOrderTimeInForce>, pub gtd_time: Option<DateTime>, pub position_fill: Option<OrderPositionFill>, pub trigger_condition: Option<OrderTriggerCondition>, pub take_profit_on_fill: Option<TakeProfitDetails>, pub stop_loss_on_fill: Option<StopLossDetails>, pub trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>, pub trade_client_extensions: Option<ClientExtensions>, pub filling_transaction_id: Option<TransactionId>, pub filled_time: Option<DateTime>, pub trade_opened_id: Option<TradeId>, pub trade_reduced_id: Option<TradeId>, pub trade_closed_ids: Vec<TradeId>, pub cancelling_transaction_id: Option<TransactionId>, pub cancelled_time: Option<DateTime>, pub replaces_order_id: Option<OrderId>, pub replaced_by_order_id: Option<OrderId>, pub partial_fill: Option<String>, pub trigger_mode: Option<String>,
}
A StopOrder is an order that is created with a price threshold, and will only be filled by a price that is equal to or worse than the threshold.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<OrderId>

The Order’s identifier, unique within the Order’s Account.

create_time: Option<DateTime>

The time when the Order was created.

state: Option<OrderState>

The state field.

client_extensions: Option<ClientExtensions>

The clientExtensions field.

instrument: Option<InstrumentName>

The Stop Order’s Instrument.

units: Option<DecimalNumber>

The quantity requested to be filled by the Stop Order. A posititive number of units results in a long Order, and a negative number of units results in a short Order.

price: Option<PriceValue>

The price threshold specified for the Stop Order. The Stop Order will only be filled by a market price that is equal to or worse than this price.

price_bound: Option<PriceValue>

The worst market price that may be used to fill this Stop Order. If the market gaps and crosses through both the price and the priceBound, the Stop Order will be cancelled instead of being filled.

time_in_force: Option<StopOrderTimeInForce>

The timeInForce field.

gtd_time: Option<DateTime>

The date/time when the Stop Order will be cancelled if its timeInForce is “GTD”.

position_fill: Option<OrderPositionFill>

The positionFill field.

trigger_condition: Option<OrderTriggerCondition>

The triggerCondition field.

take_profit_on_fill: Option<TakeProfitDetails>

The takeProfitOnFill field.

stop_loss_on_fill: Option<StopLossDetails>

The stopLossOnFill field.

trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>

The trailingStopLossOnFill field.

trade_client_extensions: Option<ClientExtensions>

The tradeClientExtensions field.

filling_transaction_id: Option<TransactionId>

ID of the Transaction that filled this Order (only provided when the Order’s state is FILLED)

filled_time: Option<DateTime>

Date/time when the Order was filled (only provided when the Order’s state is FILLED)

trade_opened_id: Option<TradeId>

Trade ID of Trade opened when the Order was filled (only provided when the Order’s state is FILLED and a Trade was opened as a result of the fill)

trade_reduced_id: Option<TradeId>

Trade ID of Trade reduced when the Order was filled (only provided when the Order’s state is FILLED and a Trade was reduced as a result of the fill)

trade_closed_ids: Vec<TradeId>

Trade IDs of Trades closed when the Order was filled (only provided when the Order’s state is FILLED and one or more Trades were closed as a result of the fill)

cancelling_transaction_id: Option<TransactionId>

ID of the Transaction that cancelled the Order (only provided when the Order’s state is CANCELLED)

cancelled_time: Option<DateTime>

Date/time when the Order was cancelled (only provided when the state of the Order is CANCELLED)

replaces_order_id: Option<OrderId>

The ID of the Order that was replaced by this Order (only provided if this Order was created as part of a cancel/replace).

replaced_by_order_id: Option<OrderId>

The ID of the Order that replaced this Order (only provided if this Order was cancelled as part of a cancel/replace).

partial_fill: Option<String>

How the Order may be partially filled. Observed value: “DEFAULT_FILL”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.

trigger_mode: Option<String>

The price trigger mode of the Order. Observed value: “TOP_OF_BOOK”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.