TrailingStopLossDetails

Struct TrailingStopLossDetails 

#[non_exhaustive]
pub struct TrailingStopLossDetails { pub distance: Option<DecimalNumber>, pub time_in_force: Option<TimeInForce>, pub gtd_time: Option<DateTime>, pub client_extensions: Option<ClientExtensions>, }
TrailingStopLossDetails specifies the details of a Trailing Stop Loss Order to be created on behalf of a client. This may happen when an Order is filled that opens a Trade requiring a Trailing Stop Loss, or when a Trade’s dependent Trailing Stop Loss Order is modified directly through the Trade.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
distance: Option<DecimalNumber>

The distance (in price units) from the Trade’s fill price that the Trailing Stop Loss Order will be triggered at.

time_in_force: Option<TimeInForce>

The timeInForce field.

gtd_time: Option<DateTime>

The date when the Trailing Stop Loss Order will be cancelled on if timeInForce is GTD.

client_extensions: Option<ClientExtensions>

The clientExtensions field.

Implementations

Source

impl TrailingStopLossDetails

pub fn at_distance(distance: DecimalNumber) -> Self

Trailing stop-loss details trailing at distance price units.