#[non_exhaustive]pub struct UnitsAvailable {
pub default: Option<UnitsAvailableDetails>,
pub reduce_first: Option<UnitsAvailableDetails>,
pub reduce_only: Option<UnitsAvailableDetails>,
pub open_only: Option<UnitsAvailableDetails>,
}Expand description
Representation of how many units of an Instrument are available to be traded by an Order depending on its postionFill option.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default: Option<UnitsAvailableDetails>The default field.
reduce_first: Option<UnitsAvailableDetails>The reduceFirst field.
reduce_only: Option<UnitsAvailableDetails>The reduceOnly field.
open_only: Option<UnitsAvailableDetails>The openOnly field.