#[non_exhaustive]pub struct ClientConfigureRejectTransaction {
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub alias: Option<String>,
pub margin_rate: Option<DecimalNumber>,
pub reject_reason: Option<TransactionRejectReason>,
}Expand description
A ClientConfigureRejectTransaction represents the reject of configuration of an Account by a client.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
alias: Option<String>The client-provided alias for the Account.
margin_rate: Option<DecimalNumber>The margin rate override for the Account.
reject_reason: Option<TransactionRejectReason>The rejectReason field.