#[non_exhaustive]pub struct CreateTransaction {
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub division_id: Option<i64>,
pub site_id: Option<i64>,
pub account_user_id: Option<i64>,
pub account_number: Option<i64>,
pub home_currency: Option<Currency>,
}Expand description
A CreateTransaction represents the creation of an Account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
division_id: Option<i64>The ID of the Division that the Account is in
site_id: Option<i64>The ID of the Site that the Account was created at
account_user_id: Option<i64>The ID of the user that the Account was created for
account_number: Option<i64>The number of the Account within the site/division/user
home_currency: Option<Currency>The home currency of the Account