#[non_exhaustive]pub struct FixedPriceOrderTransaction {Show 17 fields
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub instrument: Option<InstrumentName>,
pub units: Option<DecimalNumber>,
pub price: Option<PriceValue>,
pub position_fill: Option<OrderPositionFill>,
pub trade_state: Option<TradeState>,
pub reason: Option<FixedPriceOrderReason>,
pub client_extensions: Option<ClientExtensions>,
pub take_profit_on_fill: Option<TakeProfitDetails>,
pub stop_loss_on_fill: Option<StopLossDetails>,
pub trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>,
pub trade_client_extensions: Option<ClientExtensions>,
}Expand description
A FixedPriceOrderTransaction represents the creation of a Fixed Price Order in the user’s account. A Fixed Price Order is an Order that is filled immediately at a specified price.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
instrument: Option<InstrumentName>The Fixed Price Order’s Instrument.
units: Option<DecimalNumber>The quantity requested to be filled by the Fixed Price Order. A posititive number of units results in a long Order, and a negative number of units results in a short Order.
price: Option<PriceValue>The price specified for the Fixed Price Order. This price is the exact price that the Fixed Price Order will be filled at.
position_fill: Option<OrderPositionFill>The positionFill field.
trade_state: Option<TradeState>The tradeState field.
reason: Option<FixedPriceOrderReason>The reason field.
client_extensions: Option<ClientExtensions>The clientExtensions field.
take_profit_on_fill: Option<TakeProfitDetails>The takeProfitOnFill field.
stop_loss_on_fill: Option<StopLossDetails>The stopLossOnFill field.
trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>The trailingStopLossOnFill field.
trade_client_extensions: Option<ClientExtensions>The tradeClientExtensions field.