#[non_exhaustive]pub struct LimitOrderTransaction {Show 22 fields
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub instrument: Option<InstrumentName>,
pub units: Option<DecimalNumber>,
pub price: Option<PriceValue>,
pub time_in_force: Option<LimitOrderTimeInForce>,
pub gtd_time: Option<DateTime>,
pub position_fill: Option<OrderPositionFill>,
pub trigger_condition: Option<OrderTriggerCondition>,
pub reason: Option<LimitOrderReason>,
pub client_extensions: Option<ClientExtensions>,
pub take_profit_on_fill: Option<TakeProfitDetails>,
pub stop_loss_on_fill: Option<StopLossDetails>,
pub trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>,
pub trade_client_extensions: Option<ClientExtensions>,
pub replaces_order_id: Option<OrderId>,
pub cancelling_transaction_id: Option<TransactionId>,
pub partial_fill: Option<String>,
}Expand description
A LimitOrderTransaction represents the creation of a Limit Order in the user’s Account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
instrument: Option<InstrumentName>The Limit Order’s Instrument.
units: Option<DecimalNumber>The quantity requested to be filled by the Limit Order. A posititive number of units results in a long Order, and a negative number of units results in a short Order.
price: Option<PriceValue>The price threshold specified for the Limit Order. The Limit Order will only be filled by a market price that is equal to or better than this price.
time_in_force: Option<LimitOrderTimeInForce>The timeInForce field.
gtd_time: Option<DateTime>The date/time when the Limit Order will be cancelled if its timeInForce is “GTD”.
position_fill: Option<OrderPositionFill>The positionFill field.
trigger_condition: Option<OrderTriggerCondition>The triggerCondition field.
reason: Option<LimitOrderReason>The reason field.
client_extensions: Option<ClientExtensions>The clientExtensions field.
take_profit_on_fill: Option<TakeProfitDetails>The takeProfitOnFill field.
stop_loss_on_fill: Option<StopLossDetails>The stopLossOnFill field.
trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>The trailingStopLossOnFill field.
trade_client_extensions: Option<ClientExtensions>The tradeClientExtensions field.
replaces_order_id: Option<OrderId>The ID of the Order that this Order replaces (only provided if this Order replaces an existing Order).
cancelling_transaction_id: Option<TransactionId>The ID of the Transaction that cancels the replaced Order (only provided if this Order replaces an existing Order).
partial_fill: Option<String>How the Order may be partially filled. Observed value: “DEFAULT_FILL”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.