#[non_exhaustive]pub struct MarketOrderTransaction {Show 22 fields
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub instrument: Option<InstrumentName>,
pub units: Option<DecimalNumber>,
pub time_in_force: Option<MarketOrderTimeInForce>,
pub price_bound: Option<PriceValue>,
pub position_fill: Option<OrderPositionFill>,
pub trade_close: Option<MarketOrderTradeClose>,
pub long_position_closeout: Option<MarketOrderPositionCloseout>,
pub short_position_closeout: Option<MarketOrderPositionCloseout>,
pub margin_closeout: Option<MarketOrderMarginCloseout>,
pub delayed_trade_close: Option<MarketOrderDelayedTradeClose>,
pub reason: Option<MarketOrderReason>,
pub client_extensions: Option<ClientExtensions>,
pub take_profit_on_fill: Option<TakeProfitDetails>,
pub stop_loss_on_fill: Option<StopLossDetails>,
pub trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>,
pub trade_client_extensions: Option<ClientExtensions>,
}Expand description
A MarketOrderTransaction represents the creation of a Market Order in the user’s account. A Market Order is an Order that is filled immediately at the current market price. Market Orders can be specialized when they are created to accomplish a specific task: to close a Trade, to closeout a Position or to particiate in in a Margin closeout.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
instrument: Option<InstrumentName>The Market Order’s Instrument.
units: Option<DecimalNumber>The quantity requested to be filled by the Market Order. A posititive number of units results in a long Order, and a negative number of units results in a short Order.
time_in_force: Option<MarketOrderTimeInForce>The timeInForce field.
price_bound: Option<PriceValue>The worst price that the client is willing to have the Market Order filled at.
position_fill: Option<OrderPositionFill>The positionFill field.
trade_close: Option<MarketOrderTradeClose>The tradeClose field.
long_position_closeout: Option<MarketOrderPositionCloseout>The longPositionCloseout field.
short_position_closeout: Option<MarketOrderPositionCloseout>The shortPositionCloseout field.
margin_closeout: Option<MarketOrderMarginCloseout>The marginCloseout field.
delayed_trade_close: Option<MarketOrderDelayedTradeClose>The delayedTradeClose field.
reason: Option<MarketOrderReason>The reason field.
client_extensions: Option<ClientExtensions>The clientExtensions field.
take_profit_on_fill: Option<TakeProfitDetails>The takeProfitOnFill field.
stop_loss_on_fill: Option<StopLossDetails>The stopLossOnFill field.
trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>The trailingStopLossOnFill field.
trade_client_extensions: Option<ClientExtensions>The tradeClientExtensions field.