StopLossOrderTransaction

Struct StopLossOrderTransaction 

#[non_exhaustive]
pub struct StopLossOrderTransaction {
Show 21 fields pub id: Option<TransactionId>, pub time: Option<DateTime>, pub user_id: Option<i64>, pub account_id: Option<AccountId>, pub batch_id: Option<TransactionId>, pub request_id: Option<RequestId>, pub trade_id: Option<TradeId>, pub client_trade_id: Option<String>, pub price: Option<PriceValue>, pub distance: Option<DecimalNumber>, pub time_in_force: Option<StopLossOrderTimeInForce>, pub gtd_time: Option<DateTime>, pub trigger_condition: Option<OrderTriggerCondition>, pub guaranteed: Option<bool>, pub guaranteed_execution_premium: Option<DecimalNumber>, pub reason: Option<StopLossOrderReason>, pub client_extensions: Option<ClientExtensions>, pub order_fill_transaction_id: Option<TransactionId>, pub replaces_order_id: Option<OrderId>, pub cancelling_transaction_id: Option<TransactionId>, pub trigger_mode: Option<String>,
}
A StopLossOrderTransaction represents the creation of a StopLoss Order in the user’s Account.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<TransactionId>

The Transaction’s Identifier.

time: Option<DateTime>

The date/time when the Transaction was created.

user_id: Option<i64>

The ID of the user that initiated the creation of the Transaction.

account_id: Option<AccountId>

The ID of the Account the Transaction was created for.

batch_id: Option<TransactionId>

The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.

request_id: Option<RequestId>

The Request ID of the request which generated the transaction.

trade_id: Option<TradeId>

The ID of the Trade to close when the price threshold is breached.

client_trade_id: Option<String>

The client ID of the Trade to be closed when the price threshold is breached.

price: Option<PriceValue>

The price threshold specified for the Stop Loss Order. If the guaranteed flag is false, the associated Trade will be closed by a market price that is equal to or worse than this threshold. If the flag is true the associated Trade will be closed at this price.

distance: Option<DecimalNumber>

Specifies the distance (in price units) from the Account’s current price to use as the Stop Loss Order price. If the Trade is short the Instrument’s bid price is used, and for long Trades the ask is used.

time_in_force: Option<StopLossOrderTimeInForce>

The timeInForce field.

gtd_time: Option<DateTime>

The date/time when the StopLoss Order will be cancelled if its timeInForce is “GTD”.

trigger_condition: Option<OrderTriggerCondition>

The triggerCondition field.

guaranteed: Option<bool>

Flag indicating that the Stop Loss Order is guaranteed. The default value depends on the GuaranteedStopLossOrderMode of the account, if it is REQUIRED, the default will be true, for DISABLED or ENABLED the default is false.

guaranteed_execution_premium: Option<DecimalNumber>

The fee that will be charged if the Stop Loss Order is guaranteed and the Order is filled at the guaranteed price. The value is determined at Order creation time. It is in price units and is charged for each unit of the Trade.

reason: Option<StopLossOrderReason>

The reason field.

client_extensions: Option<ClientExtensions>

The clientExtensions field.

order_fill_transaction_id: Option<TransactionId>

The ID of the OrderFill Transaction that caused this Order to be created (only provided if this Order was created automatically when another Order was filled).

replaces_order_id: Option<OrderId>

The ID of the Order that this Order replaces (only provided if this Order replaces an existing Order).

cancelling_transaction_id: Option<TransactionId>

The ID of the Transaction that cancels the replaced Order (only provided if this Order replaces an existing Order).

trigger_mode: Option<String>

The price trigger mode of the Order. Observed value: “TOP_OF_BOOK”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.