StopOrderRejectTransaction

Struct StopOrderRejectTransaction 

#[non_exhaustive]
pub struct StopOrderRejectTransaction {
Show 24 fields pub id: Option<TransactionId>, pub time: Option<DateTime>, pub user_id: Option<i64>, pub account_id: Option<AccountId>, pub batch_id: Option<TransactionId>, pub request_id: Option<RequestId>, pub instrument: Option<InstrumentName>, pub units: Option<DecimalNumber>, pub price: Option<PriceValue>, pub price_bound: Option<PriceValue>, pub time_in_force: Option<StopOrderTimeInForce>, pub gtd_time: Option<DateTime>, pub position_fill: Option<OrderPositionFill>, pub trigger_condition: Option<OrderTriggerCondition>, pub reason: Option<StopOrderReason>, pub client_extensions: Option<ClientExtensions>, pub take_profit_on_fill: Option<TakeProfitDetails>, pub stop_loss_on_fill: Option<StopLossDetails>, pub trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>, pub trade_client_extensions: Option<ClientExtensions>, pub intended_replaces_order_id: Option<OrderId>, pub reject_reason: Option<TransactionRejectReason>, pub partial_fill: Option<String>, pub trigger_mode: Option<String>,
}
A StopOrderRejectTransaction represents the rejection of the creation of a Stop Order.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: Option<TransactionId>

The Transaction’s Identifier.

time: Option<DateTime>

The date/time when the Transaction was created.

user_id: Option<i64>

The ID of the user that initiated the creation of the Transaction.

account_id: Option<AccountId>

The ID of the Account the Transaction was created for.

batch_id: Option<TransactionId>

The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.

request_id: Option<RequestId>

The Request ID of the request which generated the transaction.

instrument: Option<InstrumentName>

The Stop Order’s Instrument.

units: Option<DecimalNumber>

The quantity requested to be filled by the Stop Order. A posititive number of units results in a long Order, and a negative number of units results in a short Order.

price: Option<PriceValue>

The price threshold specified for the Stop Order. The Stop Order will only be filled by a market price that is equal to or worse than this price.

price_bound: Option<PriceValue>

The worst market price that may be used to fill this Stop Order. If the market gaps and crosses through both the price and the priceBound, the Stop Order will be cancelled instead of being filled.

time_in_force: Option<StopOrderTimeInForce>

The timeInForce field.

gtd_time: Option<DateTime>

The date/time when the Stop Order will be cancelled if its timeInForce is “GTD”.

position_fill: Option<OrderPositionFill>

The positionFill field.

trigger_condition: Option<OrderTriggerCondition>

The triggerCondition field.

reason: Option<StopOrderReason>

The reason field.

client_extensions: Option<ClientExtensions>

The clientExtensions field.

take_profit_on_fill: Option<TakeProfitDetails>

The takeProfitOnFill field.

stop_loss_on_fill: Option<StopLossDetails>

The stopLossOnFill field.

trailing_stop_loss_on_fill: Option<TrailingStopLossDetails>

The trailingStopLossOnFill field.

trade_client_extensions: Option<ClientExtensions>

The tradeClientExtensions field.

intended_replaces_order_id: Option<OrderId>

The ID of the Order that this Order was intended to replace (only provided if this Order was intended to replace an existing Order).

reject_reason: Option<TransactionRejectReason>

The rejectReason field.

partial_fill: Option<String>

How the Order may be partially filled. Observed value: “DEFAULT_FILL”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.

trigger_mode: Option<String>

The price trigger mode of the Order. Observed value: “TOP_OF_BOOK”. This field is returned by the live v20 API but is not present in OANDA’s official documentation.