#[non_exhaustive]pub struct TakeProfitOrderTransaction {Show 17 fields
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub trade_id: Option<TradeId>,
pub client_trade_id: Option<String>,
pub price: Option<PriceValue>,
pub time_in_force: Option<TakeProfitOrderTimeInForce>,
pub gtd_time: Option<DateTime>,
pub trigger_condition: Option<OrderTriggerCondition>,
pub reason: Option<TakeProfitOrderReason>,
pub client_extensions: Option<ClientExtensions>,
pub order_fill_transaction_id: Option<TransactionId>,
pub replaces_order_id: Option<OrderId>,
pub cancelling_transaction_id: Option<TransactionId>,
}Expand description
A TakeProfitOrderTransaction represents the creation of a TakeProfit Order in the user’s Account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
trade_id: Option<TradeId>The ID of the Trade to close when the price threshold is breached.
client_trade_id: Option<String>The client ID of the Trade to be closed when the price threshold is breached.
price: Option<PriceValue>The price threshold specified for the TakeProfit Order. The associated Trade will be closed by a market price that is equal to or better than this threshold.
time_in_force: Option<TakeProfitOrderTimeInForce>The timeInForce field.
gtd_time: Option<DateTime>The date/time when the TakeProfit Order will be cancelled if its timeInForce is “GTD”.
trigger_condition: Option<OrderTriggerCondition>The triggerCondition field.
reason: Option<TakeProfitOrderReason>The reason field.
client_extensions: Option<ClientExtensions>The clientExtensions field.
order_fill_transaction_id: Option<TransactionId>The ID of the OrderFill Transaction that caused this Order to be created (only provided if this Order was created automatically when another Order was filled).
replaces_order_id: Option<OrderId>The ID of the Order that this Order replaces (only provided if this Order replaces an existing Order).
cancelling_transaction_id: Option<TransactionId>The ID of the Transaction that cancels the replaced Order (only provided if this Order replaces an existing Order).