#[non_exhaustive]pub struct TradeClientExtensionsModifyTransaction {
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub trade_id: Option<TradeId>,
pub client_trade_id: Option<String>,
pub trade_client_extensions_modify: Option<ClientExtensions>,
}Expand description
A TradeClientExtensionsModifyTransaction represents the modification of a Trade’s Client Extensions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
trade_id: Option<TradeId>The ID of the Trade who’s client extensions are to be modified.
client_trade_id: Option<String>The original Client ID of the Trade who’s client extensions are to be modified.
trade_client_extensions_modify: Option<ClientExtensions>The tradeClientExtensionsModify field.