#[non_exhaustive]pub struct TrailingStopLossOrderRejectTransaction {Show 17 fields
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub trade_id: Option<TradeId>,
pub client_trade_id: Option<String>,
pub distance: Option<DecimalNumber>,
pub time_in_force: Option<TrailingStopLossOrderTimeInForce>,
pub gtd_time: Option<DateTime>,
pub trigger_condition: Option<OrderTriggerCondition>,
pub reason: Option<TrailingStopLossOrderReason>,
pub client_extensions: Option<ClientExtensions>,
pub order_fill_transaction_id: Option<TransactionId>,
pub intended_replaces_order_id: Option<OrderId>,
pub reject_reason: Option<TransactionRejectReason>,
}Expand description
A TrailingStopLossOrderRejectTransaction represents the rejection of the creation of a TrailingStopLoss Order.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
trade_id: Option<TradeId>The ID of the Trade to close when the price threshold is breached.
client_trade_id: Option<String>The client ID of the Trade to be closed when the price threshold is breached.
distance: Option<DecimalNumber>The price distance (in price units) specified for the TrailingStopLoss Order.
time_in_force: Option<TrailingStopLossOrderTimeInForce>The timeInForce field.
gtd_time: Option<DateTime>The date/time when the StopLoss Order will be cancelled if its timeInForce is “GTD”.
trigger_condition: Option<OrderTriggerCondition>The triggerCondition field.
reason: Option<TrailingStopLossOrderReason>The reason field.
client_extensions: Option<ClientExtensions>The clientExtensions field.
order_fill_transaction_id: Option<TransactionId>The ID of the OrderFill Transaction that caused this Order to be created (only provided if this Order was created automatically when another Order was filled).
intended_replaces_order_id: Option<OrderId>The ID of the Order that this Order was intended to replace (only provided if this Order was intended to replace an existing Order).
reject_reason: Option<TransactionRejectReason>The rejectReason field.