#[non_exhaustive]pub struct StreamStats {
pub reconnects: u64,
pub failed_attempts: u64,
}Expand description
A snapshot of a managed stream’s connection statistics.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reconnects: u64Number of successful reconnects performed since the stream was created (the initial connection is not counted).
failed_attempts: u64Number of failed connection attempts since the stream was created.