#[non_exhaustive]pub struct TradeSummary {Show 21 fields
pub id: Option<TradeId>,
pub instrument: Option<InstrumentName>,
pub price: Option<PriceValue>,
pub open_time: Option<DateTime>,
pub state: Option<TradeState>,
pub initial_units: Option<DecimalNumber>,
pub initial_margin_required: Option<AccountUnits>,
pub current_units: Option<DecimalNumber>,
pub realized_pl: Option<AccountUnits>,
pub unrealized_pl: Option<AccountUnits>,
pub margin_used: Option<AccountUnits>,
pub average_close_price: Option<PriceValue>,
pub closing_transaction_ids: Vec<TransactionId>,
pub financing: Option<AccountUnits>,
pub close_time: Option<DateTime>,
pub client_extensions: Option<ClientExtensions>,
pub take_profit_order_id: Option<OrderId>,
pub stop_loss_order_id: Option<OrderId>,
pub trailing_stop_loss_order_id: Option<OrderId>,
pub dividend_adjustment: Option<DecimalNumber>,
pub true_unrealized_pl: Option<DecimalNumber>,
}Expand description
The summary of a Trade within an Account. This representation does not provide the full details of the Trade’s dependent Orders.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TradeId>The Trade’s identifier, unique within the Trade’s Account.
instrument: Option<InstrumentName>The Trade’s Instrument.
price: Option<PriceValue>The execution price of the Trade.
open_time: Option<DateTime>The date/time when the Trade was opened.
state: Option<TradeState>The state field.
initial_units: Option<DecimalNumber>The initial size of the Trade. Negative values indicate a short Trade, and positive values indicate a long Trade.
initial_margin_required: Option<AccountUnits>The margin required at the time the Trade was created. Note, this is the ‘pure’ margin required, it is not the ‘effective’ margin used that factors in the trade risk if a GSLO is attached to the trade.
current_units: Option<DecimalNumber>The number of units currently open for the Trade. This value is reduced to 0.0 as the Trade is closed.
realized_pl: Option<AccountUnits>The total profit/loss realized on the closed portion of the Trade.
unrealized_pl: Option<AccountUnits>The unrealized profit/loss on the open portion of the Trade.
margin_used: Option<AccountUnits>Margin currently used by the Trade.
average_close_price: Option<PriceValue>The average closing price of the Trade. Only present if the Trade has been closed or reduced at least once.
closing_transaction_ids: Vec<TransactionId>The IDs of the Transactions that have closed portions of this Trade.
financing: Option<AccountUnits>The financing paid/collected for this Trade.
close_time: Option<DateTime>The date/time when the Trade was fully closed. Only provided for Trades whose state is CLOSED.
client_extensions: Option<ClientExtensions>The clientExtensions field.
take_profit_order_id: Option<OrderId>ID of the Trade’s Take Profit Order, only provided if such an Order exists.
stop_loss_order_id: Option<OrderId>ID of the Trade’s Stop Loss Order, only provided if such an Order exists.
trailing_stop_loss_order_id: Option<OrderId>ID of the Trade’s Trailing Stop Loss Order, only provided if such an Order exists.
dividend_adjustment: Option<DecimalNumber>The total amount of dividend adjustment paid. This field is returned by the live v20 API but is not present in OANDA’s official documentation.
true_unrealized_pl: Option<DecimalNumber>The unrealized profit/loss inclusive of unsettled amounts. This field is returned by the live v20 API but is not present in OANDA’s official documentation.