#[non_exhaustive]pub struct DailyFinancingTransaction {
pub id: Option<TransactionId>,
pub time: Option<DateTime>,
pub user_id: Option<i64>,
pub account_id: Option<AccountId>,
pub batch_id: Option<TransactionId>,
pub request_id: Option<RequestId>,
pub financing: Option<AccountUnits>,
pub account_balance: Option<AccountUnits>,
pub account_financing_mode: Option<AccountFinancingMode>,
pub position_financings: Vec<PositionFinancing>,
pub home_conversion_cost: Option<DecimalNumber>,
pub base_home_conversion_cost: Option<DecimalNumber>,
}Expand description
A DailyFinancingTransaction represents the daily payment/collection of financing for an Account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<TransactionId>The Transaction’s Identifier.
time: Option<DateTime>The date/time when the Transaction was created.
user_id: Option<i64>The ID of the user that initiated the creation of the Transaction.
account_id: Option<AccountId>The ID of the Account the Transaction was created for.
batch_id: Option<TransactionId>The ID of the “batch” that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<RequestId>The Request ID of the request which generated the transaction.
financing: Option<AccountUnits>The amount of financing paid/collected for the Account.
account_balance: Option<AccountUnits>The Account’s balance after daily financing.
account_financing_mode: Option<AccountFinancingMode>The accountFinancingMode field.
position_financings: Vec<PositionFinancing>The financing paid/collected for each Position in the Account.
home_conversion_cost: Option<DecimalNumber>The total cost of currency conversions for the financing, in the Account’s home currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.
base_home_conversion_cost: Option<DecimalNumber>The cost of converting the base financing to the Account’s home currency. This field is returned by the live v20 API but is not present in OANDA’s official documentation.